@@ -541,7 +541,6 @@ rebuild_dir (GVfsBackendOnedrive  *self,
   GList *items;
   GError *local_error = NULL;
   gint64 *timestamp;
-  g_autofree char *id = NULL;
 
   if (parent == self->shared_with_me_dir)
     {
@@ -561,8 +560,7 @@ rebuild_dir (GVfsBackendOnedrive  *self,
 
   timestamp = g_new (gint64, 1);
   *timestamp = g_get_real_time ();
-  id = get_full_item_id (parent);
-  g_hash_table_insert (self->dir_timestamps, id, timestamp);
+  g_hash_table_insert (self->dir_timestamps, get_full_item_id (parent), timestamp);
 
   for (GList *l = items; l != NULL; l = l->next)
     {
@@ -660,8 +658,7 @@ resolve (GVfsBackendOnedrive  *self,
 
   if (out_path != NULL)
     {
-      g_autofree char *id = get_full_item_id (ret_val);
-      char *tmp  = g_build_path ("/", *out_path, id, NULL);
+      char *tmp = g_build_path ("/", *out_path, msg_drive_item_get_name (ret_val), NULL);
       g_free (*out_path);
       *out_path = tmp;
     }
@@ -1126,7 +1123,7 @@ g_vfs_backend_onedrive_make_directory (GVfsBackend          *_self,
       goto out;
     }
 
-  item_path = g_build_path ("/", parent_path, msg_drive_item_get_id (new_folder), NULL);
+  item_path = g_build_path ("/", parent_path, msg_drive_item_get_name (new_folder), NULL);
   g_debug ("  new item path: %s\n", item_path);
 
   insert_item (self, new_folder);
@@ -1218,7 +1215,18 @@ g_vfs_backend_onedrive_mount (GVfsBackend  *_self,
       item = msg_drive_service_get_root (self->service, drive, cancellable, &local_error);
       if (local_error)
         {
-          g_warning ("Could not get root: %s", local_error->message);
+          if (g_strcmp0 (local_error->message, "ObjectHandle is Invalid") == 0)
+            {
+              /* Reduce log level for this specific message as there can
+               * be drives which aren't iterable.... problem report created.
+               * https://gitlab.gnome.org/GNOME/gvfs/-/issues/763
+               */
+              g_debug ("Could not get root: %s", local_error->message);
+            }
+          else
+            {
+              g_warning ("Could not get root: %s", local_error->message);
+            }
           continue;
         }
 
@@ -1736,7 +1744,7 @@ g_vfs_backend_onedrive_create (GVfsBackend         *_self,
       goto out;
     }
 
-  item_path = g_build_path ("/", parent_path, msg_drive_item_get_id (new_item), NULL);
+  item_path = g_build_path ("/", parent_path, msg_drive_item_get_name (new_item), NULL);
   g_debug ("  new item path: %s\n", item_path);
 
   insert_item (self, new_item);
@@ -1902,7 +1910,7 @@ g_vfs_backend_onedrive_replace (GVfsBackend         *_self,
 
   if (needs_overwrite)
     {
-      item_path = g_build_path ("/", parent_path, msg_drive_item_get_id (existing_item), NULL);
+      item_path = g_build_path ("/", parent_path, msg_drive_item_get_name (existing_item), NULL);
       g_debug ("  existing item path: %s\n", item_path);
 
       error = NULL;
@@ -1930,13 +1938,21 @@ g_vfs_backend_onedrive_replace (GVfsBackend         *_self,
           goto out;
         }
 
-      item_path = g_build_filename (parent_path, msg_drive_item_get_id (MSG_DRIVE_ITEM (item)), NULL);
+      item_path = g_build_filename (parent_path, msg_drive_item_get_name (MSG_DRIVE_ITEM (item)), NULL);
       g_debug ("  new item path: %s\n", item_path);
 
       insert_item (self, MSG_DRIVE_ITEM (new_item));
       g_hash_table_foreach (self->monitors, emit_create_event, item_path);
 
-      handle = write_handle_new (MSG_DRIVE_ITEM (new_item), NULL, filename, item_path);
+      stream = msg_drive_service_update (self->service, new_item, cancellable, &error);
+      if (error != NULL)
+        {
+          g_vfs_job_failed_from_error (G_VFS_JOB (job), error);
+          g_error_free (error);
+          goto out;
+        }
+
+      handle = write_handle_new (MSG_DRIVE_ITEM (new_item), stream, filename, item_path);
     }
 
   g_vfs_job_open_for_write_set_handle (job, handle);
